package com.chelvc.framework.common.crypto;

import javax.crypto.Cipher;

import com.chelvc.framework.common.util.AESUtils;
import com.chelvc.framework.common.util.AssertUtils;
import lombok.NonNull;

/**
 * AES加解密处理器工厂实现
 *
 * @author Woody
 * @date 2024/6/25
 */
public class AESCipherFactory implements CipherFactory {
    private final String key;
    private final String name;
    private final String secret;
    private final String iv;

    public AESCipherFactory(@NonNull String secret) {
        this(secret, AESUtils.secret2iv(secret));
    }

    public AESCipherFactory(@NonNull String secret, @NonNull String iv) {
        this(AESUtils.CBC_PKCS5PADDING, secret, iv);
    }

    public AESCipherFactory(@NonNull String name, @NonNull String secret, @NonNull String iv) {
        this.key = name + secret + iv;
        this.name = name;
        this.secret = secret;
        this.iv = iv;
    }

    @Override
    public String getSecret() {
        return this.secret;
    }

    @Override
    public Cipher getCipher(int mode) {
        return AESUtils.lookupCipher(this.key, mode, () -> {
            String secret = AssertUtils.nonempty(this.secret, () -> "Cipher secret is missing");
            String iv = AssertUtils.nonempty(this.iv, () -> "Cipher iv is missing");
            return AESUtils.getCipher(this.name, mode, secret, iv);
        });
    }
}
